@@ -250,6 +250,93 @@ impl Samples {
         [22.0*SQRT_2, 23.0*SQRT_2, 24.0*SQRT_2, 62.0       , 64.0       , 66.0       ],
         [25.0*SQRT_2, 26.0*SQRT_2, 27.0*SQRT_2, 68.0       , 70.0       , 72.0       ],
     ];
+
+    pub const TENSOR4_SYM_2D_SAMPLE1: [[[[f64; 3]; 3]; 3]; 3] = [
+        // [0]
+        [
+            // [0][0]
+            [
+                [1.0, 10.0, 0.0], // [0][0][0][...]
+                [10.0, 2.0, 0.0], // [0][0][1][...]
+                [0.0, 0.0, 3.0],  // [0][0][2][...]
+            ],
+            // [0][1]
+            [
+                [19.0, 28.0, 0.0], // [0][1][0][...]
+                [28.0, 20.0, 0.0], // [0][1][1][...]
+                [0.0, 0.0, 21.0],  // [0][1][2][...]
+            ],
+            // [0][2]
+            [
+                [0.0, 0.0, 0.0], // [0][2][0][...]
+                [0.0, 0.0, 0.0], // [0][2][1][...]
+                [0.0, 0.0, 0.0], // [0][2][2][...]
+            ],
+        ],
+        // [1]
+        [
+            // [1][0]
+            [
+                [19.0, 28.0, 0.0], // [1][0][0][...]
+                [28.0, 20.0, 0.0], // [1][0][1][...]
+                [0.0, 0.0, 21.0],  // [1][0][2][...]
+            ],
+            // [1][1]
+            [
+                [4.0, 13.0, 0.0], // [1][1][0][...]
+                [13.0, 5.0, 0.0], // [1][1][1][...]
+                [0.0, 0.0, 6.0],  // [1][1][2][...]
+            ],
+            // [1][2]
+            [
+                [0.0, 0.0, 0.0], // [1][2][0][...]
+                [0.0, 0.0, 0.0], // [1][2][1][...]
+                [0.0, 0.0, 0.0], // [1][2][2][...]
+            ],
+        ],
+        // [2]
+        [
+            // [2][0]
+            [
+                [0.0, 0.0, 0.0], // [2][0][0][...]
+                [0.0, 0.0, 0.0], // [2][0][1][...]
+                [0.0, 0.0, 0.0], // [2][0][2][...]
+            ],
+            // [2][1]
+            [
+                [0.0, 0.0, 0.0], // [2][1][0][...]
+                [0.0, 0.0, 0.0], // [2][1][1][...]
+                [0.0, 0.0, 0.0], // [2][1][2][...]
+            ],
+            // [2][2]
+            [
+                [7.0, 16.0, 0.0], // [2][2][0][...]
+                [16.0, 8.0, 0.0], // [2][2][1][...]
+                [0.0, 0.0, 9.0],  // [2][2][2][...]
+            ],
+        ],
+    ];
+
+    #[rustfmt::skip]
+    pub const TENSOR4_SYM_2D_SAMPLE1_STD_MATRIX: [[f64; 9]; 9] = [
+        [ 1.0,  2.0,  3.0,  10.0, 0.0, 0.0,  10.0, 0.0, 0.0], // [0][0]...
+        [ 4.0,  5.0,  6.0,  13.0, 0.0, 0.0,  13.0, 0.0, 0.0], // [1][1]...
+        [ 7.0,  8.0,  9.0,  16.0, 0.0, 0.0,  16.0, 0.0, 0.0], // [2][2]...
+        [19.0, 20.0, 21.0,  28.0, 0.0, 0.0,  28.0, 0.0, 0.0], // [0][1]...
+        [ 0.0,  0.0,  0.0,   0.0, 0.0, 0.0,   0.0, 0.0, 0.0], // [1][2]...
+        [ 0.0,  0.0,  0.0,   0.0, 0.0, 0.0,   0.0, 0.0, 0.0], // [0][2]...
+        [19.0, 20.0, 21.0,  28.0, 0.0, 0.0,  28.0, 0.0, 0.0], // [1][0]...
+        [ 0.0,  0.0,  0.0,   0.0, 0.0, 0.0,   0.0, 0.0, 0.0], // [2][1]...
+        [ 0.0,  0.0,  0.0,   0.0, 0.0, 0.0,   0.0, 0.0, 0.0], // [2][0]...
+    ];
+
+    #[rustfmt::skip]
+    pub const TENSOR4_SYM_2D_SAMPLE1_MANDEL_MATRIX:[[f64; 4]; 4] = [
+        [ 1.0       ,  2.0       ,  3.0       , 10.0*SQRT_2],
+        [ 4.0       ,  5.0       ,  6.0       , 13.0*SQRT_2],
+        [ 7.0       ,  8.0       ,  9.0       , 16.0*SQRT_2],
+        [19.0*SQRT_2, 20.0*SQRT_2, 21.0*SQRT_2, 56.0       ],
+    ];
 }
 
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -257,16 +344,16 @@ impl Samples {
 #[cfg(test)]
 mod tests {
     use super::Samples;
-    use crate::constants::IJKL_TO_IJ;
+    use crate::constants::IJKL_TO_MN;
 
     #[test]
-    fn sample1_matches_std_matrix() {
+    fn sample1_is_ok() {
         for i in 0..3 {
             for j in 0..3 {
                 for k in 0..3 {
                     for l in 0..3 {
-                        let (a, b) = IJKL_TO_IJ[i][j][k][l];
-                        let val = Samples::TENSOR4_SAMPLE1_STD_MATRIX[a][b];
+                        let (m, n) = IJKL_TO_MN[i][j][k][l];
+                        let val = Samples::TENSOR4_SAMPLE1_STD_MATRIX[m][n];
                         assert_eq!(Samples::TENSOR4_SAMPLE1[i][j][k][l], val);
                     }
                 }
@@ -275,7 +362,7 @@ mod tests {
     }
 
     #[test]
-    fn components_of_sample2_are_correct() {
+    fn sample2_is_ok() {
         for i in 0..3 {
             for j in 0..3 {
                 for k in 0..3 {
@@ -289,12 +376,12 @@ mod tests {
     }
 
     #[test]
-    fn sample1_sym_matches_std_matrix() {
+    fn sample1_sym_is_ok() {
         for i in 0..3 {
             for j in 0..3 {
                 for k in 0..3 {
                     for l in 0..3 {
-                        let (a, b) = IJKL_TO_IJ[i][j][k][l];
+                        let (a, b) = IJKL_TO_MN[i][j][k][l];
                         let val = Samples::TENSOR4_SYM_SAMPLE1_STD_MATRIX[a][b];
                         assert_eq!(Samples::TENSOR4_SYM_SAMPLE1[i][j][k][l], val);
                     }
@@ -302,4 +389,19 @@ mod tests {
             }
         }
     }
+
+    #[test]
+    fn sample1_sym_2d_is_ok() {
+        for i in 0..3 {
+            for j in 0..3 {
+                for k in 0..3 {
+                    for l in 0..3 {
+                        let (m, n) = IJKL_TO_MN[i][j][k][l];
+                        let val = Samples::TENSOR4_SYM_2D_SAMPLE1_STD_MATRIX[m][n];
+                        assert_eq!(Samples::TENSOR4_SYM_2D_SAMPLE1[i][j][k][l], val);
+                    }
+                }
+            }
+        }
+    }
 }
